monitor

package
v0.9.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 19, 2026 License: MIT Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckPIDLiveness

func CheckPIDLiveness(sessions []session.Session)

CheckPIDLiveness marks sessions with dead PIDs as "exited". Sessions record the OS they were created on. When the monitor runs on a different OS (e.g. Windows .exe reading WSL sessions), it uses the appropriate method to check each PID.

func RenderOnce

func RenderOnce(sessions []session.Session, width int, debug bool) string

RenderOnce produces a single snapshot of the current sessions for non-interactive output.

Types

type Model

type Model struct {
	// contains filtered or unexported fields
}

Model holds the state for the Bubble Tea program.

func New

func New(sessionsDir string, debug bool) Model

New creates a new monitor model that reads from the given directory.

func (Model) Init

func (m Model) Init() tea.Cmd

func (Model) Update

func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd)

func (Model) View

func (m Model) View() string

Jump to